@@ -1,7 +1,7 @@
 #! /bin/bash
 _ARCH="x86_64"
-source /usr/lib/archboot/functions
-source /usr/lib/archboot/server_functions
+. /usr/lib/archboot/common.sh
+. /usr/lib/archboot/server.sh
 _root_check
 _update_source
 _x86_64_pacman_use_default || exit 1
