@@ -22,17 +22,17 @@ usage () {
     echo -e " \033[1m-u\033[0m               Update scripts: setup, quickinst, tz, km and helpers."
     echo -e ""
     echo -e " \033[1m-latest\033[0m          Launch latest archboot environment (using kexec)."
-    echo -e "                  This operation needs at least \033[1m1.9 GB RAM\033[0m."
+    echo -e "                  This operation needs at least \033[1m2.3 GB RAM\033[0m."
     echo ""
     echo -e " \033[1m-latest-install\033[0m  Launch latest archboot environment with downloaded"
     echo -e "                  package cache (using kexec)."
-    echo -e "                  This operation needs at least \033[1m2.6 GB RAM\033[0m."
+    echo -e "                  This operation needs at least \033[1m3.2 GB RAM\033[0m."
     echo ""
     echo -e " \033[1m-latest-image\033[0m    Generate latest image files in /archboot directory"
-    echo -e "                  This operation needs at least \033[1m3.5 GB RAM\033[0m."
+    echo -e "                  This operation needs at least \033[1m5.0 GB RAM\033[0m."
     echo ""
     echo -e " \033[1m-launch-xfce\033[0m     Launch XFCE desktop with VNC sharing enabled."
-    echo -e "                  This operation needs at least \033[1m3.2 GB RAM\033[0m."
+    echo -e "                  This operation needs at least \033[1m3.5 GB RAM\033[0m."
     echo ""
     echo -e " \033[1m-h\033[0m               This message."
     exit 0
@@ -230,25 +230,48 @@ _kexec() {
         sleep 1
     done
 }
+_cleanup_xfce() {
+    echo "Cleanup archboot environment ..."
+    rm -rf /usr/share/{man,info,doc,gtk-doc,ibus,perl5}
+    rm -rf /usr/include
+    rm -rf /usr/lib/libgo.*
+}
 
 _launch_xfce() {
-    X_PACKAGES="xorg xfce4 libtiff glib2 chromium libcups gcc-libs glibc harfbuzz avahi nss breeze-icons tigervnc perl p11-kit libp11-kit"
+    X_PACKAGES="llvm-libs gcc-libs perl glibc xorg libtiff glib2 chromium libcups harfbuzz \
+    avahi nss breeze-icons tigervnc p11-kit libp11-kit gvfs fuse tpm2-tss \
+    libsecret gparted gvfs-smb smbclient libcap tevent libbsd libldap tdb ldb \
+    libmd jansson libsasl xfce4 thunar-archive-plugin thunar-volman file-roller \
+    nss-mdns gnome-keyring"
+    # try to save RAM by calling the cleanup hook and installing each package alone
     if [[ -e /var/cache/pacman/pkg/archboot.db ]]; then
         echo "Install packages ..."
         _INSTALL_SOURCE="file:///var/cache/pacman/pkg"
         _create_pacman_conf
-        #shellcheck disable=SC2086
-        pacman -Sy ${X_PACKAGES} --config ${_PACMAN_CONF} --noconfirm || exit 1
+        pacman -Sy --config ${_PACMAN_CONF}
+        for i in ${X_PACKAGES}; do
+            #shellcheck disable=SC2086
+            pacman -S ${i} --config ${_PACMAN_CONF} --noconfirm || exit 1
+            _cleanup_xfce
+        done
     else
         echo "Updating environment ..."
-        pacman -Syu --ignore linux --ignore linux-firmware --noconfirm || exit 1
+        pacman -Syu --ignore linux --ignore linux-firmware --ignore linux-firmware-marvell --noconfirm || exit 1
+        _clean_xfce
         echo "Install packages ..."
-        #shellcheck disable=SC2086
-        pacman -Sy ${X_PACKAGES} --noconfirm || exit 1
+        for i in ${X_PACKAGES}; do
+            #shellcheck disable=SC2086
+            pacman -S ${i} --noconfirm || exit 1
+            _clean_xfce
+        done
     fi
-    echo "Cleanup archboot environment ..."
-    rm -r /usr/share/{locale,man,info,doc,gtk-doc,ibus}
-    rm -r /usr/include
+    # fix locale
+    echo "Fix locale ..."
+    sed -i -e 's:#C.UTF-8 UTF-8:C.UTF-8 UTF-8:g' "${1}/etc/locale.gen"
+    locale-gen
+    rm -rf /usr/share/{locale,i18n}
+    # replace appfinder with archboot setup
+    sed -i -e 's#xfce4-appfinder#archboot#g' /etc/xdg/xfce4/panel/default.xml
     echo "Fix chromium startup ..."
     # fix chromium startup
     cat << EOF >/etc/chromium-flags.conf
@@ -261,8 +284,66 @@ EOF
     # breeze icons
     sed -i -e 's#<property name="IconThemeName" type="string" value="Adwaita"/>#<property name="IconThemeName" type="string" value="breeze"/>#g' \
     /etc/xdg/xfce4/xfconf/xfce-perchannel-xml/xsettings.xml
-    sed -i -e '/xfce4-run.desktop/i <Filename>archboot.desktop</Filename>' /etc/xdg/menus/xfce-applications.menu
     sed -i -e 's#firefox#chromium#g' /etc/xdg/xfce4/helpers.rc
+    # fix gparted.desktop
+    sed -i -e 's#Categories=.*#Categories=X-Xfce-Toplevel;#g' /usr/share/applications/gparted.desktop
+    # xfce menu
+    cat << EOF >/etc/xdg/menus/xfce-applications.menu
+<!DOCTYPE Menu PUBLIC "-//freedesktop//DTD Menu 1.0//EN"
+  "http://www.freedesktop.org/standards/menu-spec/1.0/menu.dtd">
+
+<Menu>
+    <Name>Xfce</Name>
+
+    <DefaultAppDirs/>
+    <DefaultDirectoryDirs/>
+
+    <Include>
+        <Category>X-Xfce-Toplevel</Category>
+    </Include>
+
+    <Layout>
+	<Filename>archboot.desktop</Filename>
+        <Filename>gparted.desktop</Filename>
+        <Filename>xfce4-run.desktop</Filename>
+        <Separator/>
+        <Filename>xfce4-terminal-emulator.desktop</Filename>
+        <Filename>xfce4-file-manager.desktop</Filename>
+	<Filename>xfce4-web-browser.desktop</Filename>
+        <Separator/>
+        <Menuname>Settings</Menuname>
+        <Separator/>
+        <Merge type="all"/>
+        <Separator/>
+        <Filename>xfce4-session-logout.desktop</Filename>
+    </Layout>
+
+    <Menu>
+        <Name>Settings</Name>
+        <Directory>xfce-settings.directory</Directory>
+        <Include>
+            <Category>Settings</Category>
+        </Include>
+
+        <Layout>
+            <Filename>xfce-settings-manager.desktop</Filename>
+            <Separator/>
+            <Merge type="all"/>
+        </Layout>
+
+        <Menu>
+            <Name>Screensavers</Name>
+            <Directory>xfce-screensavers.directory</Directory>
+            <Include>
+                <Category>Screensaver</Category>
+            </Include>
+        </Menu>
+    </Menu>
+
+    <DefaultMergeDirs/>
+
+</Menu>
+EOF
     # background image
     cat << EOF >/etc/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-desktop.xml
 <?xml version="1.0" encoding="UTF-8"?>
@@ -300,6 +381,10 @@ EOF
   </property>
 </channel>
 EOF
+    # hide menu entries
+    for i in xfce4-mail-reader xfce4-about; do
+        echo 'NoDisplay=true' >> /usr/share/applications/$i.desktop
+    done
     echo "Autostart setup ..."
     cat << EOF > /etc/xdg/autostart/archboot.desktop
 [Desktop Entry]
@@ -319,11 +404,8 @@ Name=Tigervnc
 Exec=x0vncserver -rfbauth /etc/tigervnc/passwd
 EOF
     cp /etc/xdg/autostart/archboot.desktop /usr/share/applications/archboot.desktop
-    echo "Hide menu entries ..."
-    # hide menu entries
-    for i in xfce4-mail-reader qv4l2 qvidcap bssh bvnc avahi-discover fluid; do
-        echo 'NoDisplay=true' >> /usr/share/applications/$i.desktop
-    done
+    echo "Starting avahi-daemon ..."
+    systemctl start avahi-daemon.service
     echo "Launching XFCE ..."
     startxfce4
 }
